==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/classes_8.js <==
var searchData=
[
  ['iagsestimator',['IAGSEstimator',['../structfsdk_1_1_i_a_g_s_estimator.html',1,'fsdk']]],
  ['iarchive',['IArchive',['../structfsdk_1_1_i_archive.html',1,'fsdk']]],
  ['iasynccontext',['IAsyncContext',['../structfsdk_1_1_i_async_context.html',1,'fsdk']]],
  ['ibackgroundestimator',['IBackgroundEstimator',['../structfsdk_1_1_i_background_estimator.html',1,'fsdk']]],
  ['ibestshotqualityestimator',['IBestShotQualityEstimator',['../structfsdk_1_1_i_best_shot_quality_estimator.html',1,'fsdk']]],
  ['iblackwhiteestimator',['IBlackWhiteEstimator',['../structfsdk_1_1_i_black_white_estimator.html',1,'fsdk']]],
  ['icredibilitycheckestimator',['ICredibilityCheckEstimator',['../structfsdk_1_1_i_credibility_check_estimator.html',1,'fsdk']]],
  ['icrowdestimator',['ICrowdEstimator',['../structfsdk_1_1_i_crowd_estimator.html',1,'fsdk']]],
  ['idatastorageobject',['IDataStorageObject',['../structfsdk_1_1_i_data_storage_object.html',1,'fsdk']]],
  ['ideepfakeestimator',['IDeepFakeEstimator',['../structfsdk_1_1experimental_1_1_i_deep_fake_estimator.html',1,'fsdk::experimental']]],
  ['idenseindex',['IDenseIndex',['../structfsdk_1_1_i_dense_index.html',1,'fsdk']]],
  ['idepthlivenessestimator',['IDepthLivenessEstimator',['../structfsdk_1_1_i_depth_liveness_estimator.html',1,'fsdk']]],
  ['idescriptor',['IDescriptor',['../structfsdk_1_1_i_descriptor.html',1,'fsdk']]],
  ['idescriptorbatch',['IDescriptorBatch',['../structfsdk_1_1_i_descriptor_batch.html',1,'fsdk']]],
  ['idescriptorextractor',['IDescriptorExtractor',['../structfsdk_1_1_i_descriptor_extractor.html',1,'fsdk']]],
  ['idescriptormatcher',['IDescriptorMatcher',['../structfsdk_1_1_i_descriptor_matcher.html',1,'fsdk']]],
  ['idetectionbatch',['IDetectionBatch',['../structfsdk_1_1_i_detection_batch.html',1,'fsdk']]],
  ['idetectioncomparer',['IDetectionComparer',['../classfsdk_1_1_i_detection_comparer.html',1,'fsdk']]],
  ['idetector',['IDetector',['../structfsdk_1_1_i_detector.html',1,'fsdk']]],
  ['idynamicdescriptorstorage',['IDynamicDescriptorStorage',['../structfsdk_1_1_i_dynamic_descriptor_storage.html',1,'fsdk']]],
  ['idynamicindex',['IDynamicIndex',['../structfsdk_1_1_i_dynamic_index.html',1,'fsdk']]],
  ['idynamicrangeestimator',['IDynamicRangeEstimator',['../structfsdk_1_1_i_dynamic_range_estimator.html',1,'fsdk']]],
  ['iemotionsestimator',['IEmotionsEstimator',['../structfsdk_1_1_i_emotions_estimator.html',1,'fsdk']]],
  ['iethnicityestimator',['IEthnicityEstimator',['../structfsdk_1_1_i_ethnicity_estimator.html',1,'fsdk']]],
  ['ieyebrowestimator',['IEyeBrowEstimator',['../structfsdk_1_1_i_eye_brow_estimator.html',1,'fsdk']]],
  ['ieyeestimator',['IEyeEstimator',['../structfsdk_1_1_i_eye_estimator.html',1,'fsdk']]],
  ['ifacedetectionbatch',['IFaceDetectionBatch',['../structfsdk_1_1_i_face_detection_batch.html',1,'fsdk']]],
  ['ifaceengine',['IFaceEngine',['../structfsdk_1_1_i_face_engine.html',1,'fsdk']]],
  ['ifaceenginepos',['IFaceEnginePos',['../structfsdk_1_1_i_face_engine_pos.html',1,'fsdk']]],
  ['ifacelandmarksbatch',['IFaceLandmarksBatch',['../structfsdk_1_1_i_face_landmarks_batch.html',1,'fsdk']]],
  ['ifacelandmarksdetector',['IFaceLandmarksDetector',['../structfsdk_1_1_i_face_landmarks_detector.html',1,'fsdk']]],
  ['ifaceocclusionestimator',['IFaceOcclusionEstimator',['../structfsdk_1_1_i_face_occlusion_estimator.html',1,'fsdk']]],
  ['ifacialhairestimator',['IFacialHairEstimator',['../structfsdk_1_1_i_facial_hair_estimator.html',1,'fsdk']]],
  ['ifightsestimator',['IFightsEstimator',['../structfsdk_1_1_i_fights_estimator.html',1,'fsdk']]],
  ['ifightsestimatorcontext',['IFightsEstimatorContext',['../structfsdk_1_1_i_fights_estimator_context.html',1,'fsdk']]],
  ['ifisheyeestimator',['IFishEyeEstimator',['../structfsdk_1_1_i_fish_eye_estimator.html',1,'fsdk']]],
  ['igazeestimator',['IGazeEstimator',['../structfsdk_1_1_i_gaze_estimator.html',1,'fsdk']]],
  ['iglassesestimator',['IGlassesEstimator',['../structfsdk_1_1_i_glasses_estimator.html',1,'fsdk']]],
  ['iheaddetector',['IHeadDetector',['../structfsdk_1_1_i_head_detector.html',1,'fsdk']]],
  ['iheadposeestimator',['IHeadPoseEstimator',['../structfsdk_1_1_i_head_pose_estimator.html',1,'fsdk']]],
  ['iheadwearestimator',['IHeadWearEstimator',['../structfsdk_1_1_i_head_wear_estimator.html',1,'fsdk']]],
  ['ihumanattributeestimator',['IHumanAttributeEstimator',['../structfsdk_1_1_i_human_attribute_estimator.html',1,'fsdk']]],
  ['ihumandetectionbatch',['IHumanDetectionBatch',['../structfsdk_1_1_i_human_detection_batch.html',1,'fsdk']]],
  ['ihumandetector',['IHumanDetector',['../structfsdk_1_1_i_human_detector.html',1,'fsdk']]],
  ['ihumanfacebatch',['IHumanFaceBatch',['../structfsdk_1_1_i_human_face_batch.html',1,'fsdk']]],
  ['ihumanfacedetector',['IHumanFaceDetector',['../structfsdk_1_1_i_human_face_detector.html',1,'fsdk']]],
  ['ihumanwarper',['IHumanWarper',['../structfsdk_1_1_i_human_warper.html',1,'fsdk']]],
  ['iidmap',['IIDMap',['../structfsdk_1_1_i_i_d_map.html',1,'fsdk']]],
  ['iimagemodificationestimator',['IImageModificationEstimator',['../structfsdk_1_1_i_image_modification_estimator.html',1,'fsdk']]],
  ['iimagesbatch',['IImagesBatch',['../structfsdk_1_1_i_images_batch.html',1,'fsdk']]],
  ['iimagetransfer',['IImageTransfer',['../structfsdk_1_1_i_image_transfer.html',1,'fsdk']]],
  ['iindex',['IIndex',['../structfsdk_1_1_i_index.html',1,'fsdk']]],
  ['iindexbuilder',['IIndexBuilder',['../structfsdk_1_1_i_index_builder.html',1,'fsdk']]],
  ['ilicense',['ILicense',['../structfsdk_1_1_i_license.html',1,'fsdk']]],
  ['ilivenessdepthestimator',['ILivenessDepthEstimator',['../structfsdk_1_1_i_liveness_depth_estimator.html',1,'fsdk']]],
  ['ilivenessdepthrgbestimator',['ILivenessDepthRGBEstimator',['../structfsdk_1_1_i_liveness_depth_r_g_b_estimator.html',1,'fsdk']]],
  ['ilivenessflyingfacesestimator',['ILivenessFlyingFacesEstimator',['../structfsdk_1_1_i_liveness_flying_faces_estimator.html',1,'fsdk']]],
  ['ilivenessfprestimator',['ILivenessFPREstimator',['../structfsdk_1_1_i_liveness_f_p_r_estimator.html',1,'fsdk']]],
  ['ilivenessirestimator',['ILivenessIREstimator',['../structfsdk_1_1_i_liveness_i_r_estimator.html',1,'fsdk']]],
  ['ilivenessoneshotrgbestimator',['ILivenessOneShotRGBEstimator',['../structfsdk_1_1_i_liveness_one_shot_r_g_b_estimator.html',1,'fsdk']]],
  ['ilivenessrgbmestimator',['ILivenessRGBMEstimator',['../structfsdk_1_1_i_liveness_r_g_b_m_estimator.html',1,'fsdk']]],
  ['image',['Image',['../structfsdk_1_1_image.html',1,'fsdk']]],
  ['imagecolorestimation',['ImageColorEstimation',['../structfsdk_1_1_image_color_estimation.html',1,'fsdk']]],
  ['imagemodificationestimation',['ImageModificationEstimation',['../structfsdk_1_1_image_modification_estimation.html',1,'fsdk']]],
  ['imedicalmaskestimator',['IMedicalMaskEstimator',['../structfsdk_1_1_i_medical_mask_estimator.html',1,'fsdk']]],
  ['imouthestimator',['IMouthEstimator',['../structfsdk_1_1_i_mouth_estimator.html',1,'fsdk']]],
  ['inaturallightestimator',['INaturalLightEstimator',['../structfsdk_1_1_i_natural_light_estimator.html',1,'fsdk']]],
  ['inirlivenessestimator',['INIRLivenessEstimator',['../structfsdk_1_1_i_n_i_r_liveness_estimator.html',1,'fsdk']]],
  ['int1',['Int1',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int1.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['int2',['Int2',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int2.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['int3',['Int3',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int3.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['int4',['Int4',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int4.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['iorientationestimator',['IOrientationEstimator',['../structfsdk_1_1_i_orientation_estimator.html',1,'fsdk']]],
  ['ioverlapestimator',['IOverlapEstimator',['../structfsdk_1_1_i_overlap_estimator.html',1,'fsdk']]],
  ['ipointbatch',['IPointBatch',['../structfsdk_1_1_i_point_batch.html',1,'fsdk']]],
  ['iportraitstyleestimator',['IPortraitStyleEstimator',['../structfsdk_1_1_i_portrait_style_estimator.html',1,'fsdk']]],
  ['ippeestimator',['IPPEEstimator',['../structfsdk_1_1_i_p_p_e_estimator.html',1,'fsdk']]],
  ['iprogresstracker',['IProgressTracker',['../structfsdk_1_1_i_progress_tracker.html',1,'fsdk']]],
  ['iqualityestimator',['IQualityEstimator',['../structfsdk_1_1_i_quality_estimator.html',1,'fsdk']]],
  ['iredeyeestimator',['IRedEyeEstimator',['../structfsdk_1_1_i_red_eye_estimator.html',1,'fsdk']]],
  ['irefcounted',['IRefCounted',['../structfsdk_1_1_i_ref_counted.html',1,'fsdk']]],
  ['irestimation',['IREstimation',['../structfsdk_1_1_i_r_estimation.html',1,'fsdk']]],
  ['iresultbatch',['IResultBatch',['../structfsdk_1_1_i_result_batch.html',1,'fsdk']]],
  ['iserializableobject',['ISerializableObject',['../structfsdk_1_1_i_serializable_object.html',1,'fsdk']]],
  ['isettingsprovider',['ISettingsProvider',['../structfsdk_1_1_i_settings_provider.html',1,'fsdk']]],
  ['istaticdescriptorstorage',['IStaticDescriptorStorage',['../structfsdk_1_1_i_static_descriptor_storage.html',1,'fsdk']]],
  ['iwarper',['IWarper',['../structfsdk_1_1_i_warper.html',1,'fsdk']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/classes_8.js <==
var searchData=
[
  ['iagsestimator',['IAGSEstimator',['../structfsdk_1_1_i_a_g_s_estimator.html',1,'fsdk']]],
  ['iarchive',['IArchive',['../structfsdk_1_1_i_archive.html',1,'fsdk']]],
  ['iasynccontext',['IAsyncContext',['../structfsdk_1_1_i_async_context.html',1,'fsdk']]],
  ['ibackgroundestimator',['IBackgroundEstimator',['../structfsdk_1_1_i_background_estimator.html',1,'fsdk']]],
  ['ibestshotqualityestimator',['IBestShotQualityEstimator',['../structfsdk_1_1_i_best_shot_quality_estimator.html',1,'fsdk']]],
  ['iblackwhiteestimator',['IBlackWhiteEstimator',['../structfsdk_1_1_i_black_white_estimator.html',1,'fsdk']]],
  ['icredibilitycheckestimator',['ICredibilityCheckEstimator',['../structfsdk_1_1_i_credibility_check_estimator.html',1,'fsdk']]],
  ['icrowdestimator',['ICrowdEstimator',['../structfsdk_1_1_i_crowd_estimator.html',1,'fsdk']]],
  ['idatastorageobject',['IDataStorageObject',['../structfsdk_1_1_i_data_storage_object.html',1,'fsdk']]],
  ['ideepfakeestimator',['IDeepFakeEstimator',['../structfsdk_1_1experimental_1_1_i_deep_fake_estimator.html',1,'fsdk::experimental']]],
  ['idenseindex',['IDenseIndex',['../structfsdk_1_1_i_dense_index.html',1,'fsdk']]],
  ['idepthlivenessestimator',['IDepthLivenessEstimator',['../structfsdk_1_1_i_depth_liveness_estimator.html',1,'fsdk']]],
  ['idescriptor',['IDescriptor',['../structfsdk_1_1_i_descriptor.html',1,'fsdk']]],
  ['idescriptorbatch',['IDescriptorBatch',['../structfsdk_1_1_i_descriptor_batch.html',1,'fsdk']]],
  ['idescriptorextractor',['IDescriptorExtractor',['../structfsdk_1_1_i_descriptor_extractor.html',1,'fsdk']]],
  ['idescriptormatcher',['IDescriptorMatcher',['../structfsdk_1_1_i_descriptor_matcher.html',1,'fsdk']]],
  ['idetectionbatch',['IDetectionBatch',['../structfsdk_1_1_i_detection_batch.html',1,'fsdk']]],
  ['idetectioncomparer',['IDetectionComparer',['../classfsdk_1_1_i_detection_comparer.html',1,'fsdk']]],
  ['idetector',['IDetector',['../structfsdk_1_1_i_detector.html',1,'fsdk']]],
  ['idynamicdescriptorstorage',['IDynamicDescriptorStorage',['../structfsdk_1_1_i_dynamic_descriptor_storage.html',1,'fsdk']]],
  ['idynamicindex',['IDynamicIndex',['../structfsdk_1_1_i_dynamic_index.html',1,'fsdk']]],
  ['idynamicrangeestimator',['IDynamicRangeEstimator',['../structfsdk_1_1_i_dynamic_range_estimator.html',1,'fsdk']]],
  ['iemotionsestimator',['IEmotionsEstimator',['../structfsdk_1_1_i_emotions_estimator.html',1,'fsdk']]],
  ['iethnicityestimator',['IEthnicityEstimator',['../structfsdk_1_1_i_ethnicity_estimator.html',1,'fsdk']]],
  ['ieyebrowestimator',['IEyeBrowEstimator',['../structfsdk_1_1_i_eye_brow_estimator.html',1,'fsdk']]],
  ['ieyeestimator',['IEyeEstimator',['../structfsdk_1_1_i_eye_estimator.html',1,'fsdk']]],
  ['ifacedetectionbatch',['IFaceDetectionBatch',['../structfsdk_1_1_i_face_detection_batch.html',1,'fsdk']]],
  ['ifaceengine',['IFaceEngine',['../structfsdk_1_1_i_face_engine.html',1,'fsdk']]],
  ['ifaceenginepos',['IFaceEnginePos',['../structfsdk_1_1_i_face_engine_pos.html',1,'fsdk']]],
  ['ifacelandmarksbatch',['IFaceLandmarksBatch',['../structfsdk_1_1_i_face_landmarks_batch.html',1,'fsdk']]],
  ['ifacelandmarksdetector',['IFaceLandmarksDetector',['../structfsdk_1_1_i_face_landmarks_detector.html',1,'fsdk']]],
  ['ifaceocclusionestimator',['IFaceOcclusionEstimator',['../structfsdk_1_1_i_face_occlusion_estimator.html',1,'fsdk']]],
  ['ifacialhairestimator',['IFacialHairEstimator',['../structfsdk_1_1_i_facial_hair_estimator.html',1,'fsdk']]],
  ['ifightsestimator',['IFightsEstimator',['../structfsdk_1_1_i_fights_estimator.html',1,'fsdk']]],
  ['ifightsestimatorcontext',['IFightsEstimatorContext',['../structfsdk_1_1_i_fights_estimator_context.html',1,'fsdk']]],
  ['ifisheyeestimator',['IFishEyeEstimator',['../structfsdk_1_1_i_fish_eye_estimator.html',1,'fsdk']]],
  ['igazeestimator',['IGazeEstimator',['../structfsdk_1_1_i_gaze_estimator.html',1,'fsdk']]],
  ['iglassesestimator',['IGlassesEstimator',['../structfsdk_1_1_i_glasses_estimator.html',1,'fsdk']]],
  ['iheaddetector',['IHeadDetector',['../structfsdk_1_1_i_head_detector.html',1,'fsdk']]],
  ['iheadposeestimator',['IHeadPoseEstimator',['../structfsdk_1_1_i_head_pose_estimator.html',1,'fsdk']]],
  ['iheadwearestimator',['IHeadWearEstimator',['../structfsdk_1_1_i_head_wear_estimator.html',1,'fsdk']]],
  ['ihumanattributeestimator',['IHumanAttributeEstimator',['../structfsdk_1_1_i_human_attribute_estimator.html',1,'fsdk']]],
  ['ihumandetectionbatch',['IHumanDetectionBatch',['../structfsdk_1_1_i_human_detection_batch.html',1,'fsdk']]],
  ['ihumandetector',['IHumanDetector',['../structfsdk_1_1_i_human_detector.html',1,'fsdk']]],
  ['ihumanfacebatch',['IHumanFaceBatch',['../structfsdk_1_1_i_human_face_batch.html',1,'fsdk']]],
  ['ihumanfacedetector',['IHumanFaceDetector',['../structfsdk_1_1_i_human_face_detector.html',1,'fsdk']]],
  ['ihumanwarper',['IHumanWarper',['../structfsdk_1_1_i_human_warper.html',1,'fsdk']]],
  ['iidmap',['IIDMap',['../structfsdk_1_1_i_i_d_map.html',1,'fsdk']]],
  ['iimagemodificationestimator',['IImageModificationEstimator',['../structfsdk_1_1_i_image_modification_estimator.html',1,'fsdk']]],
  ['iimagesbatch',['IImagesBatch',['../structfsdk_1_1_i_images_batch.html',1,'fsdk']]],
  ['iimagetransfer',['IImageTransfer',['../structfsdk_1_1_i_image_transfer.html',1,'fsdk']]],
  ['iindex',['IIndex',['../structfsdk_1_1_i_index.html',1,'fsdk']]],
  ['iindexbuilder',['IIndexBuilder',['../structfsdk_1_1_i_index_builder.html',1,'fsdk']]],
  ['ilicense',['ILicense',['../structfsdk_1_1_i_license.html',1,'fsdk']]],
  ['ilivenessdepthestimator',['ILivenessDepthEstimator',['../structfsdk_1_1_i_liveness_depth_estimator.html',1,'fsdk']]],
  ['ilivenessdepthrgbestimator',['ILivenessDepthRGBEstimator',['../structfsdk_1_1_i_liveness_depth_r_g_b_estimator.html',1,'fsdk']]],
  ['ilivenessflyingfacesestimator',['ILivenessFlyingFacesEstimator',['../structfsdk_1_1_i_liveness_flying_faces_estimator.html',1,'fsdk']]],
  ['ilivenessoneshotrgbestimator',['ILivenessOneShotRGBEstimator',['../structfsdk_1_1_i_liveness_one_shot_r_g_b_estimator.html',1,'fsdk']]],
  ['ilivenessrgbmestimator',['ILivenessRGBMEstimator',['../structfsdk_1_1_i_liveness_r_g_b_m_estimator.html',1,'fsdk']]],
  ['image',['Image',['../structfsdk_1_1_image.html',1,'fsdk']]],
  ['imagecolorestimation',['ImageColorEstimation',['../structfsdk_1_1_image_color_estimation.html',1,'fsdk']]],
  ['imagemodificationestimation',['ImageModificationEstimation',['../structfsdk_1_1_image_modification_estimation.html',1,'fsdk']]],
  ['imedicalmaskestimator',['IMedicalMaskEstimator',['../structfsdk_1_1_i_medical_mask_estimator.html',1,'fsdk']]],
  ['imouthestimator',['IMouthEstimator',['../structfsdk_1_1_i_mouth_estimator.html',1,'fsdk']]],
  ['inaturallightestimator',['INaturalLightEstimator',['../structfsdk_1_1_i_natural_light_estimator.html',1,'fsdk']]],
  ['inirlivenessestimator',['INIRLivenessEstimator',['../structfsdk_1_1_i_n_i_r_liveness_estimator.html',1,'fsdk']]],
  ['int1',['Int1',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int1.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['int2',['Int2',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int2.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['int3',['Int3',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int3.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['int4',['Int4',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int4.html',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['iorientationestimator',['IOrientationEstimator',['../structfsdk_1_1_i_orientation_estimator.html',1,'fsdk']]],
  ['ioverlapestimator',['IOverlapEstimator',['../structfsdk_1_1_i_overlap_estimator.html',1,'fsdk']]],
  ['ipointbatch',['IPointBatch',['../structfsdk_1_1_i_point_batch.html',1,'fsdk']]],
  ['iportraitstyleestimator',['IPortraitStyleEstimator',['../structfsdk_1_1_i_portrait_style_estimator.html',1,'fsdk']]],
  ['ippeestimator',['IPPEEstimator',['../structfsdk_1_1_i_p_p_e_estimator.html',1,'fsdk']]],
  ['iprogresstracker',['IProgressTracker',['../structfsdk_1_1_i_progress_tracker.html',1,'fsdk']]],
  ['iqualityestimator',['IQualityEstimator',['../structfsdk_1_1_i_quality_estimator.html',1,'fsdk']]],
  ['iredeyeestimator',['IRedEyeEstimator',['../structfsdk_1_1_i_red_eye_estimator.html',1,'fsdk']]],
  ['irefcounted',['IRefCounted',['../structfsdk_1_1_i_ref_counted.html',1,'fsdk']]],
  ['iresultbatch',['IResultBatch',['../structfsdk_1_1_i_result_batch.html',1,'fsdk']]],
  ['iserializableobject',['ISerializableObject',['../structfsdk_1_1_i_serializable_object.html',1,'fsdk']]],
  ['isettingsprovider',['ISettingsProvider',['../structfsdk_1_1_i_settings_provider.html',1,'fsdk']]],
  ['istaticdescriptorstorage',['IStaticDescriptorStorage',['../structfsdk_1_1_i_static_descriptor_storage.html',1,'fsdk']]],
  ['isubjectivequalityestimator',['ISubjectiveQualityEstimator',['../structfsdk_1_1_i_subjective_quality_estimator.html',1,'fsdk']]],
  ['iwarper',['IWarper',['../structfsdk_1_1_i_warper.html',1,'fsdk']]]
];
